@@ -1,12 +1,14 @@
+"""The operator module holds implementations of objects such as the operator enum."""
 from enum import Enum
 
 
 class Operator(Enum):
     """Operator is a representation of mathematical comparison symbols.
-     This can be used on tasks that execute conditionally based on the output of another task.
-    Notes
-    -----
-    The task that outputs its result needs to do so using stdout. See `examples` for a sample workflow.
+
+    This can be used on tasks that execute conditionally based on the output of another task.
+
+    Notes:
+        The task that outputs its result needs to do so using stdout. See `examples` for a sample workflow.
     """
 
     does_not_exist = "DoesNotExist"
@@ -26,7 +28,8 @@ class Operator(Enum):
     and_ = "&&"
     starts_with = "=~"
 
-    def __str__(self):
+    def __str__(self) -> str:
+        """Assembles the `value` representation of the enum and returns it as a string."""
         return str(self.value)
 
 
